@@ -23,7 +23,7 @@ from errorhandler import ErrorHandler
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.alert import Alert
-from selenium.common.exceptions import WebDriverException
+
 
 class WebDriver(object):
     """
@@ -51,7 +51,7 @@ class WebDriver(object):
         if desired_capabilities is None:
             raise WebDriverException("Desired Capabilities can't be None")
         self.command_executor = command_executor
-        if type(self.command_executor) is str:
+        if type(self.command_executor) is str or type(self.command_executor) is unicode:
             self.command_executor = RemoteConnection(command_executor)
         self.session_id = None
         self.capabilities = {}
