@@ -214,7 +214,7 @@ class WebElement(object):
     def _upload(self, filename):
         fp = StringIO()
         zipped = zipfile.ZipFile(fp, 'w', zipfile.ZIP_DEFLATED)
-        zipped.write(filename)
+        zipped.write(filename, filename.split('/')[-1])
         zipped.close()
         try:
             return self._execute(Command.UPLOAD_FILE, 
@@ -222,6 +222,10 @@ class WebElement(object):
         except WebDriverException as e:
             if "Unrecognized command: POST" in e.__str__():
                 return filename
+            elif "Command not found: POST " in e.__str__():
+                return filename
+            elif '{"status":405,"value":["GET","HEAD","DELETE"]}' in e.__str__():
+                return filename
             else:
                 raise e
 
